@@ -51,7 +51,7 @@ new_defaults = function(value = list()) {
 #' Below is a list of default chunk options, retrieved via
 #' \code{tex_opts$get()}:
 #'
-#' These options correspond to fields in the direct call to \code{\link{texPreview}}, which are listed in explained
+#' These options correspond to fields in the direct call to \code{\link{tex_preview}}, which are listed in explained
 #' 
 #' in the help manual.
 #'
@@ -60,16 +60,17 @@ new_defaults = function(value = list()) {
 #'   \code{tex_opts_current$get()}.
 #' @export
 #' @concept opts
-#' @examples tex_opts$get('margin')
+#' @examples tex_opts$get()
 tex_opts = new_defaults(list(
   fileDir = NULL,
   margin = list(left = 10, top=5, right=10, bottom=5),
   imgFormat = "png",
   print.xtable.opts = list(),
   opts.html = list(width="100%",height="100%"),
-  cleanup = c('aux','log','Doc'),
+  cleanup = c('aux','log','txt','Doc'),
   engine = 'pdflatex',
   returnType = 'viewer',
+  usrPackages = NULL,
   density = 150,
   resizebox=TRUE,
   svg_max = 80000
